CommitKey

Struct CommitKey 

pub struct CommitKey { /* private fields */ }
CommitKey is used to commit to a polynomial which is bounded by the max_degree.

Implementations

Source

impl CommitKey

pub fn to_raw_var_bytes(&self) -> Vec<u8>

Serialize the CommitKey into bytes.

This operation is designed to store the raw representation of the contents of the CommitKey. Therefore, the size of the bytes outputed by this function is expected to be the double than the one that CommitKey::to_bytes.

Note

This function should be used when we want to serialize the CommitKey allowing a really fast deserialization later. This functions output should not be used by the regular CommitKey::from_bytes fn.

pub unsafe fn from_slice_unchecked(bytes: &[u8]) -> Self

Deserialize CommitKey from a set of bytes created by CommitKey::to_raw_var_bytes.

The bytes source is expected to be trusted and no check will be performed reggarding the points security

Safety

This function will not produce any memory errors but can deal to the generation of invalid or unsafe points/keys. To make sure this does not happen, the inputed bytes must match the ones that were generated by the encoding functions of this lib.

pub fn to_var_bytes(&self) -> Vec<u8>

Serializes the CommitKey into a byte slice.

pub fn from_slice(bytes: &[u8]) -> Result<CommitKey, Error>

Deserialize a slice of bytes into a CommitKey struct performing security and consistency checks for each point that the bytes contain.

Note

This function can be really slow if the CommitKey has a certain degree/size. If the bytes come from a trusted source such as a local file, we recommend to use CommitKey::from_slice_unchecked and CommitKey::to_raw_var_bytes.