Error

Enum Error 

pub enum Error {
Show 19 variants InvalidEvalDomainSize { log_size_of_group: u32, adacity: u32, }, ProofVerificationError, CircuitInputsNotFound, UninitializedPIGenerator, InvalidPublicInputBytes, CircuitAlreadyPreprocessed, MismatchedPolyLen, DegreeIsZero, TruncatedDegreeTooLarge, TruncatedDegreeIsZero, PolynomialDegreeTooLarge, PolynomialDegreeIsZero, PairingCheckFailure, BytesError(Error), NotEnoughBytes, PointMalformed, BlsScalarMalformed, ElementNotIndexed, TablePreProcessingError,
}
Defines all possible errors that can be encountered in PLONK.

Variants



InvalidEvalDomainSize

This error occurs when an error triggers on any of the fft module functions.

Fields

log_size_of_group: u32

Log size of the group

adacity: u32

Two adacity generated



ProofVerificationError

This error occurs when a proof verification fails.



CircuitInputsNotFound

This error occurs when the circuit is not provided with all of the required inputs.



UninitializedPIGenerator

This error occurs when we want to verify a Proof but the pi_constructor attribute is uninitialized.



InvalidPublicInputBytes

PublicInput serialization error



CircuitAlreadyPreprocessed

This error occurs when the Prover structure already contains a preprocessed circuit inside, but you call preprocess again.



MismatchedPolyLen

This error occurs when an error triggers during the preprocessing stage.



DegreeIsZero

This error occurs when the user tries to create PublicParameters and supplies the max degree as zero.



TruncatedDegreeTooLarge

This error occurs when the user tries to trim PublicParameters to a degree that is larger than the maximum degree.



TruncatedDegreeIsZero

This error occurs when the user tries to trim PublicParameters down to a degree that is zero.



PolynomialDegreeTooLarge

This error occurs when the user tries to commit to a polynomial whose degree is larger than the supported degree for that proving key.



PolynomialDegreeIsZero

This error occurs when the user tries to commit to a polynomial whose degree is zero.



PairingCheckFailure

This error occurs when the pairing check fails at being equal to the Identity point.



BytesError(Error)

Dusk-bytes serialization error



NotEnoughBytes

This error occurs when there are not enough bytes to read out of a slice during deserialization.



PointMalformed

This error occurs when a malformed point is decoded from a byte array.



BlsScalarMalformed

This error occurs when a malformed BLS scalar is decoded from a byte array.



ElementNotIndexed

Query element not found in lookup table



TablePreProcessingError

Cannot commit to table column polynomial